@@ -2,7 +2,7 @@ set -e
 
 distro=$1;
 
-PATH=/usr/local/bin:/opt/rakudo-pkg/bin/:~/.perl6/bin:$PATH
+PATH=/usr/local/bin:/opt/rakudo-pkg/bin/:~/.raku/bin:$PATH
 
 if test "$distro" = "localhost"; then
 
